@@ -927,50 +927,52 @@ class MessageIO(Device):
 
 
 # Note: has_target means that a target field is there, not that the device
-# is considered read-only.
+# is considered read-only. For this use readonly....
 Type = namedtuple(
     'Type',
-    'devcls value_fmt num_values has_target status_size num_params has_pctrl')
+    'devcls value_fmt num_values has_target readonly status_size num_params has_pctrl')
 
 
 TYPECODE_MAP = {
-    0x1201: Type(SimpleDiscreteIn,  'h', 1, False, 0, 0, False),
-    0x1202: Type(SimpleDiscreteIn,  'i', 1, False, 0, 0, False),
-    0x1204: Type(SimpleDiscreteIn,  'q', 1, False, 0, 0, False),
-    0x1302: Type(SimpleAnalogIn,    'f', 1, False, 0, 0, False),
-    0x1304: Type(SimpleAnalogIn,    'd', 1, False, 0, 0, False),
-    0x1401: Type(Keyword,           'H', 1, False, 0, 0, False),
-    0x1402: Type(Keyword,           'I', 1, False, 0, 0, False),
-    0x1404: Type(Keyword,           'Q', 1, False, 0, 0, False),
-    0x1502: Type(RealValue,         'f', 1, False, 0, 0, False),
-    0x1504: Type(RealValue,         'd', 1, False, 0, 0, False),
-    0x1602: Type(SimpleDiscreteOut, 'h', 1, True,  0, 0, False),
-    0x1604: Type(SimpleDiscreteOut, 'i', 1, True,  0, 0, False),
-    0x1608: Type(SimpleDiscreteOut, 'q', 1, True,  0, 0, False),
-    0x1704: Type(SimpleAnalogOut,   'f', 1, True,  0, 0, False),
-    0x1708: Type(SimpleAnalogOut,   'd', 1, True,  0, 0, False),
-    0x1801: Type(StatusWord,        'H', 1, False, 2, 0, False),
-    0x1802: Type(StatusWord,        'I', 1, False, 4, 0, False),
-    0x1a02: Type(DiscreteIn,        'h', 1, False, 2, 0, False),
-    0x1a04: Type(DiscreteIn,        'i', 1, False, 4, 0, False),
-    0x1a08: Type(DiscreteIn,        'q', 1, False, 6, 0, False),
-    0x1b03: Type(AnalogIn,          'f', 1, False, 2, 0, False),
-    0x1b04: Type(AnalogIn,          'f', 1, False, 4, 0, False),
-    0x1b08: Type(AnalogIn,          'd', 1, False, 6, 0, False),
-    0x1e03: Type(DiscreteOut,       'h', 1, True,  2, 0, False),
-    0x1e04: Type(DiscreteOut,       'h', 1, True,  4, 0, False),
-    0x1e06: Type(DiscreteOut,       'i', 1, True,  4, 0, False),
-    0x1e0c: Type(DiscreteOut,       'q', 1, True,  6, 0, False),
-    0x1f05: Type(AnalogOut,         'f', 1, True,  2, 0, False),
-    0x1f06: Type(AnalogOut,         'f', 1, True,  4, 0, False),
-    0x1f0c: Type(AnalogOut,         'd', 1, True,  6, 0, False),
+    0x1201: Type(SimpleDiscreteIn,  'h', 1, False, True,  0, 0, False),
+    0x1202: Type(SimpleDiscreteIn,  'i', 1, False, True,  0, 0, False),
+    0x1204: Type(SimpleDiscreteIn,  'q', 1, False, True,  0, 0, False),
+    0x1302: Type(SimpleAnalogIn,    'f', 1, False, True,  0, 0, False),
+    0x1304: Type(SimpleAnalogIn,    'd', 1, False, True,  0, 0, False),
+    0x1401: Type(Keyword,           'H', 1, False, False, 0, 0, False),
+    0x1402: Type(Keyword,           'I', 1, False, False, 0, 0, False),
+    0x1404: Type(Keyword,           'Q', 1, False, False, 0, 0, False),
+    0x1502: Type(RealValue,         'f', 1, False, False, 0, 0, False),
+    0x1504: Type(RealValue,         'd', 1, False, False, 0, 0, False),
+    0x1602: Type(SimpleDiscreteOut, 'h', 1, True,  False, 0, 0, False),
+    0x1604: Type(SimpleDiscreteOut, 'i', 1, True,  False, 0, 0, False),
+    0x1608: Type(SimpleDiscreteOut, 'q', 1, True,  False, 0, 0, False),
+    0x1704: Type(SimpleAnalogOut,   'f', 1, True,  False, 0, 0, False),
+    0x1708: Type(SimpleAnalogOut,   'd', 1, True,  False, 0, 0, False),
+    # changeable via start/Stop/reset/...
+    0x1801: Type(StatusWord,        'H', 1, False, True,  2, 0, False),
+    # changeable via start/Stop/reset/...
+    0x1802: Type(StatusWord,        'I', 1, False, True,  4, 0, False),
+    0x1a02: Type(DiscreteIn,        'h', 1, False, True,  2, 0, False),
+    0x1a04: Type(DiscreteIn,        'i', 1, False, True,  4, 0, False),
+    0x1a08: Type(DiscreteIn,        'q', 1, False, True,  6, 0, False),
+    0x1b03: Type(AnalogIn,          'f', 1, False, True,  2, 0, False),
+    0x1b04: Type(AnalogIn,          'f', 1, False, True,  4, 0, False),
+    0x1b08: Type(AnalogIn,          'd', 1, False, True,  6, 0, False),
+    0x1e03: Type(DiscreteOut,       'h', 1, True,  False, 2, 0, False),
+    0x1e04: Type(DiscreteOut,       'h', 1, True,  False, 4, 0, False),
+    0x1e06: Type(DiscreteOut,       'i', 1, True,  False, 4, 0, False),
+    0x1e0c: Type(DiscreteOut,       'q', 1, True,  False, 6, 0, False),
+    0x1f05: Type(AnalogOut,         'f', 1, True,  False, 2, 0, False),
+    0x1f06: Type(AnalogOut,         'f', 1, True,  False, 4, 0, False),
+    0x1f0c: Type(AnalogOut,         'd', 1, True,  False, 6, 0, False),
 
-    0x4006: Type(ParamIn,           'f', 1, False, 2, 1, True),
-    0x4008: Type(ParamIn,           'f', 1, False, 6, 1, True),
-    0x400c: Type(ParamIn,           'd', 1, False, 6, 1, True),
-    0x5008: Type(ParamOut,          'f', 1, True,  2, 1, True),
-    0x500a: Type(ParamOut,          'f', 1, True,  6, 1, True),
-    0x5010: Type(ParamOut,          'd', 1, True,  6, 1, True),
+    0x4006: Type(ParamIn,           'f', 1, False, True,  2, 1, True),
+    0x4008: Type(ParamIn,           'f', 1, False, True,  6, 1, True),
+    0x400c: Type(ParamIn,           'd', 1, False, True,  6, 1, True),
+    0x5008: Type(ParamOut,          'f', 1, True,  False, 2, 1, True),
+    0x500a: Type(ParamOut,          'f', 1, True,  False, 6, 1, True),
+    0x5010: Type(ParamOut,          'd', 1, True,  False, 6, 1, True),
 }
 
 for n in range(16):
@@ -980,12 +982,12 @@ for n in range(16):
     lfout32 = 0x3000 | (n << 8) | ( 8 + 2 * n)
     fout32 =  0x7000 | (n << 8) | ( 8 + 2 * n)
     fout64 =  0x3000 | (n << 8) | (16 + 4 * n)
-    TYPECODE_MAP[lfin32]  = Type(FlatIn, 'f', 1, False, 2, n + 1, False)
-    TYPECODE_MAP[fin32]   = Type(FlatIn, 'f', 1, False, 4, n + 1, False)
-    TYPECODE_MAP[fin64]   = Type(FlatIn, 'd', 1, False, 6, n + 1, False)
-    TYPECODE_MAP[lfout32] = Type(FlatOut, 'f', 1, True, 2, n + 1, False)
-    TYPECODE_MAP[fout32]  = Type(FlatOut, 'f', 1, True, 4, n + 1, False)
-    TYPECODE_MAP[fout64]  = Type(FlatOut, 'd', 1, True, 6, n + 1, False)
+    TYPECODE_MAP[lfin32]  = Type(FlatIn, 'f', 1, False, True, 2, n + 1, False)
+    TYPECODE_MAP[fin32]   = Type(FlatIn, 'f', 1, False, True, 4, n + 1, False)
+    TYPECODE_MAP[fin64]   = Type(FlatIn, 'd', 1, False, True, 6, n + 1, False)
+    TYPECODE_MAP[lfout32] = Type(FlatOut, 'f', 1, True, False, 2, n + 1, False)
+    TYPECODE_MAP[fout32]  = Type(FlatOut, 'f', 1, True, False, 4, n + 1, False)
+    TYPECODE_MAP[fout64]  = Type(FlatOut, 'd', 1, True, False, 6, n + 1, False)
 
     if n == 0:
         continue
@@ -994,16 +996,16 @@ for n in range(16):
     vin64 =  0x4000 | (n << 8) | (12 + 4 * n)
     vout32 = 0x5000 | (n << 8) | ( 8 + 4 * n)
     vout64 = 0x5000 | (n << 8) | (16 + 8 * n)
-    TYPECODE_MAP[vin32]      = Type(VectorIn,  'f', n + 1, False, 2, 1, True)
-    TYPECODE_MAP[vin32 + 2]  = Type(VectorIn,  'f', n + 1, False, 6, 1, True)
-    TYPECODE_MAP[vin64]      = Type(VectorIn,  'd', n + 1, False, 6, 1, True)
-    TYPECODE_MAP[vout32]     = Type(VectorOut, 'f', n + 1, True,  2, 1, True)
-    TYPECODE_MAP[vout32 + 2] = Type(VectorOut, 'f', n + 1, True,  6, 1, True)
-    TYPECODE_MAP[vout64]     = Type(VectorOut, 'd', n + 1, True,  6, 1, True)
+    TYPECODE_MAP[vin32]      = Type(VectorIn,  'f', n + 1, False, True, 2, 1, True)
+    TYPECODE_MAP[vin32 + 2]  = Type(VectorIn,  'f', n + 1, False, True, 6, 1, True)
+    TYPECODE_MAP[vin64]      = Type(VectorIn,  'd', n + 1, False, True, 6, 1, True)
+    TYPECODE_MAP[vout32]     = Type(VectorOut, 'f', n + 1, True, False, 2, 1, True)
+    TYPECODE_MAP[vout32 + 2] = Type(VectorOut, 'f', n + 1, True, False, 6, 1, True)
+    TYPECODE_MAP[vout64]     = Type(VectorOut, 'd', n + 1, True, False, 6, 1, True)
 
 for n in range(4, 253, 2):
     msgio = 0x0500 | (n >> 1)
-    TYPECODE_MAP[msgio] = Type(MessageIO, f'{n-2}s', 1, False, 0, 0, False)
+    TYPECODE_MAP[msgio] = Type(MessageIO, f'{n-2}s', 1, False, True, 0, 0, False)
 
 
 def typecode_description(typecode):
