@@ -69,6 +69,13 @@ class PlcIO:
     def stop_cache(self):
         self.cache.stop()
 
+    def disconnect(self):
+        """Close the connection. This PlcIO object should not be used anymore
+        afterwards.
+        """
+        self.stop_cache()
+        self.proto.disconnect()
+
     # Cache related API.
 
     def register_cache_range(self, addr, length):
