@@ -28,7 +28,8 @@ from zapf import Error
 ADDRESSES = '''Valid addresses:
 ads://host[:port]/amsnetid:amsport
 modbus://host[:port]/slaveno
-tango://dbhost:dbport/tango/device/name'''
+tango://dbhost:dbport/tango/device/name
+sim://filepath'''
 
 
 class Protocol:
