@@ -49,17 +49,17 @@ class TangoProtocol(Protocol):
 
         if not TANGO_ADDR_RE.match(url):
             raise ApiError('invalid Tango address, must be '
-                           'ads://host/amsnetid:amsport')
+                           'tango://[database:port/]domain/family/member[#dbase=no]')
         self._proxy = None
 
-        Protocol.__init__(self, url, log)
+        super().__init__(url, log)
 
     def connect(self):
         try:
             self._proxy = PyTango.DeviceProxy(self.url)
             self._proxy.state
         except PyTango.DevFailed as err:
-            raise CommError('cannot connect to Tango device: %s' % err) from err
+            raise CommError(f'cannot connect to Tango device: {err}') from err
         except AttributeError:
             raise CommError('Tango device exists, but seems to be not '
                             'running') from None
@@ -103,7 +103,7 @@ class TangoProtocol(Protocol):
             result = self._proxy.ReadInputBytes((addr, length))  # no offset
         except PyTango.DevFailed as err:
             self.log.exception('during read')
-            raise CommError('Tango error during read: %s' % err) from err
+            raise CommError(f'Tango error during read: {err}') from err
         return bytes(result)
 
     def _write_ads(self, addr, data):
@@ -112,8 +112,8 @@ class TangoProtocol(Protocol):
         try:
             self._proxy.WriteOutputBytes(((addr,) + tuple(data)))
         except PyTango.DevFailed as err:
-            self.log.exception('during read')
-            raise CommError('Tango error during read: %s' % err) from err
+            self.log.exception('during write')
+            raise CommError(f'Tango error during write: {err}') from err
 
     # I/O using a Modbus Tango device
 
@@ -127,17 +127,17 @@ class TangoProtocol(Protocol):
                                                   nregs))
         except PyTango.DevFailed as err:
             self.log.exception('during read')
-            raise CommError('Tango error during read: %s' % err) from err
-        return pack('<%dH' % nregs, *result)[:length]
+            raise CommError(f'Tango error during read: {err}') from err
+        return pack(f'<{nregs}H', *result)[:length]
 
     def _write_modbus(self, addr, data):
         if not self.connected:
             self.reconnect()
         assert addr % 2 == 0 and len(data) % 2 == 0
         nregs = len(data) // 2
-        payload = ((self.offset + addr) // 2,) + unpack('<%dH' % nregs, data)
+        payload = ((self.offset + addr) // 2,) + unpack(f'<{nregs}H', data)
         try:
             self._proxy.WriteOutputWords(payload)
         except PyTango.DevFailed as err:
-            self.log.exception('during read')
-            raise CommError('Tango error during read: %s' % err) from err
+            self.log.exception('during write')
+            raise CommError(f'Tango error during write: {err}') from err
