@@ -67,6 +67,11 @@ class Scanner:
         Entangle interface specification.
 
         Example: ``tango://192.168.201.2:10000/box/plc/ads``
+
+    ``sim://filepath``
+        "Connection" to a software-simulated PLC.  Zapf starts it in the same
+        process when the address is requested.  See the `zapf.simulator`
+        package for details.
     """
 
     IGNORE_BAD_DEVICES = True
@@ -286,9 +291,7 @@ class Scanner:
                         params[par.pop('name')] = par
 
             basetype, width = FMT_TO_BASETYPE.get(tce.value_fmt, (None, 0))
-            # Keyword/RealValue are special
-            access = 'rw' if (tce.has_target or typecode >> 8 in (0x14, 0x15)) \
-                else 'ro'
+            access = 'ro' if tce.readonly else 'rw'
 
             # fixup limits, if needed
             limits = FMT_LIMITS.get(tce.value_fmt)
